View source: R/replace_lead_whitespaces_ind.R
| replace_lead_whitespaces_ind | R Documentation |
Replace leading whitespaces with left indentation RTF markup
replace_lead_whitespaces_ind(x)
x |
|
The following function receives a string 'x' and returns a modified string where every leading whitespace is replaced with 90 twips (0.0625 inches) left indentation RTF markup. If the input does not start with a whitespace, the string is returned as is.
character(1) RTF markup with leading whitespaces replaced.
tidytlg:::replace_lead_whitespaces_ind(" this is x")
# [1] "\intbl\li360\fi0 this is x"
tidytlg:::replace_lead_whitespaces_ind("this is x")
# [1] "this is x"
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.